SubmoduleAddOptions

Struct SubmoduleAddOptions 

pub struct SubmoduleAddOptions {
    pub name: SubmoduleName,
    pub path: PathBuf,
    pub url: String,
    pub branch: Option<SerializableBranch>,
    pub ignore: Option<SerializableIgnore>,
    pub update: Option<SerializableUpdate>,
    pub fetch_recurse: Option<SerializableFetchRecurse>,
    pub shallow: bool,
    pub no_init: bool,
}
Options for adding a submodule

Fields

name: SubmoduleName

Name of the submodule

path: PathBuf

Local path where the submodule will be checked out

url: String

URL of the submodule repository

branch: Option<SerializableBranch>

Branch to track (optional)

ignore: Option<SerializableIgnore>

Ignore rule for the submodule (optional)

update: Option<SerializableUpdate>

Update strategy for the submodule (optional)

fetch_recurse: Option<SerializableFetchRecurse>

Fetch recurse setting (optional)

shallow: bool

Whether to create a shallow clone

no_init: bool

Whether to skip initialization after adding

Implementations

Source

impl SubmoduleAddOptions

pub fn into_submodule_entry(self) -> SubmoduleEntry

Create an add options from a SubmoduleEntry

pub fn from_submodule_entries_tuple( entry: (SubmoduleName, SubmoduleEntry), ) -> Self

Create an add options from a entries tuple (name and SubmoduleEntry)

pub fn into_entries_tuple(self) -> (SubmoduleName, SubmoduleEntry)

Convert an AddOptions to a SubmoduleEntries tuple